<?php

namespace Teknisa\MAN\Services;

use Doctrine\ORM\EntityManager;
use Teknisa\MAN\Utilities;

class RelatoriosVendaProduto {

	public function __construct(EntityManager $entityManager) {
        $this->entityManager = $entityManager;
    }
    
    public function getParams($conditions){
        $params = array(
         	":CDFILIAL"   => $conditions['CDFILIAL'],
         	":TCDFILIAL"  => $conditions['TCDFILIAL'],
         	":CDCAIXA"    => $conditions['CDCAIXA'],
         	":TCDCAIXA"   => $conditions['TCDCAIXA'],
         	":DTVENDAINI" => $conditions['DTVENDAINI'],
         	":DTVENDAFIN" => $conditions['DTVENDAFIN'],
         	
         	":CDARVPRODF" => $conditions['CDARVPRODF'],
         	":CDARVPRODI" => $conditions['CDARVPRODI'],
         	":CDPRODLIST" => $conditions['CDPRODLIST'],
         	":PRODNIV"    => $conditions['PRODNIV'],
         	":TCDPRODUTO" => $conditions['TCDPRODUTO'],
         	
         	":CDTIPOCONS"  => $conditions['CDTIPOCONS'],
         	":TCDTIPOCONS" => $conditions['TCDTIPOCONS'],
         	":MODALIDADE"  => $conditions['MODALIDADE'],

         	":NRORG"       => $conditions['NRORG']
 		);
 		return $params;
    }
    
    
    public function findRelatorio($conditions) {
        $params = $this->getParams($conditions); 
        $query = $this->getSQL($conditions['TIPORELATORIO'], $conditions['IDTPPRODUTO']);
        if($conditions['IDTPPRODUTO'] == 'V') {
            return $this->entityManager->getConnection()->fetchAll($query, $params);
        } else if($conditions['IDTPPRODUTO'] == 'C') {
            return $this->buscaProdutoPai($params, $conditions);
        } else { 
            $produtosVenda = $this->entityManager->getConnection()->fetchAll($query, $params);
            $produtosCombinados = $this->buscaProdutoPai($params, $conditions);
            
            foreach($produtosVenda as $key => $prod) {
                if($prod['CDPRODPROMOCAO'] !== null || $prod['IDIMPPRGRPROMO'] == 'S') {
                    unset($produtosVenda[$key]);
                }
            }
            
            return array_merge($produtosVenda, $produtosCombinados);
        }
    }
    
    public function buscaProdutoPai($params, $conditions) {
        $row = array();
        $rowPai = array();
        $queryPai = $this->getSQLPai($conditions['TIPORELATORIO']);
        
		$param = array(
     	    ":CDFILIAL"    => $params[':CDFILIAL'],
     	    ":TCDPRODUTO"  => ($params[':TCDPRODUTO'] == 'T') ?  "T" : "N",
     	    ":PRODINI"     => $params[':CDARVPRODI'],
     	    ":PRODFIM"     => $params[':CDARVPRODF'],
     	    ":P_DTINI"     => $params[':DTVENDAINI'],
     	    ":P_DTFIM"     => $params[':DTVENDAFIN'],
     	    ":MODALIDADE"  => $params[':MODALIDADE'],
     	    ":CDPRODLIST"  => $params[':CDPRODLIST'],
     	    ":TCDPRODUTO"  => $params[':TCDPRODUTO'],
     	    ":P_TCDFILIAL" => ($params[':TCDFILIAL'] == 'T') ?  "T" : "N",
     	    ":CDCAIXA"     => $params[':CDCAIXA'],
         	":TCDCAIXA"    => $params[':TCDCAIXA'],
         	":CDTIPOCONS"  => $params[':CDTIPOCONS'],
         	":TCDTIPOCONS" => $params[':TCDTIPOCONS'],
         	":PRODNIV"     => $params[':PRODNIV'],
     	    ":NRORG"       => $params[':NRORG']
 		);
 		
		$rowPai = $this->entityManager->getConnection()->fetchAll($queryPai, $param);
	    $rowFilho   = array();
        
	 	if($rowPai){
            $rowFilho = $this->buscaProdFilho($rowPai, $rowFilho, $conditions);
	 	}
	 	else{
	 		return $row;
	 	}
        
	 	for($i = 0; count($rowFilho) > $i; $i++){
	 		for($j = 0; count($rowFilho[$i]) > $j; $j++){
	 		$row[]= $rowFilho[$i][$j];
	 		}
	 	}
	 	
	    return $row;
    }
    
    public function buscaProdFilho($rowPai, $rowFilho, $conditions) {
        $i = 0;
        $queryFilho = $this->getSQLFilho($conditions['TIPORELATORIO']);
        
        for($j = 0; count($rowPai) > $j; $j++){
			$param = array(
			    ":CDFILIAL"    => $rowPai[$j]["CDFILIAL"],
			    ":CDPRODPAI"   => $rowPai[$j]["CDPRODPAI"],
			    ":TIPO"        => $rowPai[$j]["TIPO"],
			    ":P_DTINI"     => ($conditions['TIPORELATORIO'] == 'D') ?  $rowPai[$j]['DTENTRVENDA'] : $conditions['DTVENDAINI'],
		   	    ":P_DTFIM"     => ($conditions['TIPORELATORIO'] == 'D') ?  $rowPai[$j]['DTENTRVENDA'] : $conditions['DTVENDAFIN'],
		   	    ":CDTIPOCONS"  => $conditions['CDTIPOCONS'],
         	    ":TCDTIPOCONS" => $conditions['TCDTIPOCONS'],
         	    ":CDCAIXA"     => $conditions['CDCAIXA'],
         	    ":TCDCAIXA"    => $conditions['TCDCAIXA'],
        	    ":MODALIDADE"  => $rowPai[$j]["IDORIGEMVENDA"],
		   	    ":NRORG"       => $conditions['NRORG']
			);

			$rowFilho[$j] = $this->entityManager->getConnection()->fetchAll($queryFilho, $param);
			$totalVend = 0;
			$somaImprimeSim = 0;
		 		
            foreach($rowFilho[$j] as $rowEach){
		     	$totalVend += $rowEach['TOTALVENDFIL'];
		    }

		    for($i = 0; count($rowFilho[$j]) > $i; $i++){
		        if ($rowPai[$j]["TIPO"] == 2) {
		     	    $paramQT = array(
		 		       ":TIPO" => $rowPai[$j]["TIPO"],
		 		       ":CDPRODPAI" => $rowPai[$j]["CDPRODPAI"],
		 		       ":DTVENDAINI" => ($conditions['TIPORELATORIO'] == 'D') ?  $rowPai[$j]['DTENTRVENDA'] : $conditions['DTVENDAINI'],
		 		       ":DTVENDAFIN" => ($conditions['TIPORELATORIO'] == 'D') ?  $rowPai[$j]['DTENTRVENDA'] : $conditions['DTVENDAFIN']
		     		);
		 		   $QTPROD = $this->entityManager->getConnection()->fetchAll(self::GET_QT_PROD_PROM, $paramQT)[0]['NRITEMPROMO'];
		     	}
		     	$rowFilho[$j][$i]['TAXAAFINIDADE'] = $rowFilho[$j][$i]["QTPRODVEND"]/($rowPai[$j]['QUANTPRODPAI'] == 0 ? 1:$rowPai[$j]['QUANTPRODPAI'])*100;
		     	$rowFilho[$j][$i]['LABELFILIAL'] = $rowPai[$j]["CDFILIAL"]." - ".$rowPai[$j]["NMFILIAL"];
		     	$rowFilho[$j][$i]['NRCUPONS'] = $rowPai[$j]['NRCUPONS'];
		     	$rowFilho[$j][$i]['NMMODALIDADE'] = $rowPai[$j]['NMMODALIDADE'];
		     	$vlr = round(($totalVend / ($rowPai[$j]['NRCUPONS'] == 0 ? 1 :$rowPai[$j]['NRCUPONS'])),2);
		     	$rowFilho[$j][$i]['VLRMEDIOCUP'] = str_replace('.', ',' ,$vlr );
		     	if($conditions['TIPORELATORIO'] == 'D') {
		     	    $rowFilho[$j][$i]['LABELPRODPROMOCAO'] = "Promoção Combinada: ".$rowPai[$j]['LABELPRODPROMOCAO']." | "."Nr. de Cupons: ".$rowPai[$j]['NRCUPONS']." | "."Qtde. Vendida: ".(isset($QTPROD) ? round($rowPai[$j]['QUANTPRODPAI']/( $QTPROD == 0? 1 : $QTPROD), 3) : $rowPai[$j]['QUANTPRODPAI'])." | "."Valor Médio Cupom: ".$rowFilho[$j][$i]['VLRMEDIOCUP']." | "."Valor Venda: R$".number_format($rowPai[$j]['TOTALVENDA'], 2, ',', '.')." | "."Data: ".$rowPai[$j]['DTENTRVENDA'];
		     	} else {
		     	    $rowFilho[$j][$i]['LABELPRODPROMOCAO'] = "Promoção Combinada: ".$rowPai[$j]['LABELPRODPROMOCAO']." | "."Nr. de Cupons: ".$rowPai[$j]['NRCUPONS']." | "."Qtde. Vendida: ".(isset($QTPROD) ? round($rowPai[$j]['QUANTPRODPAI']/( $QTPROD == 0? 1 : $QTPROD), 3) : $rowPai[$j]['QUANTPRODPAI'])." | "."Valor Médio Cupom: ".$rowFilho[$j][$i]['VLRMEDIOCUP']." | "."Valor Venda: R$".number_format($rowPai[$j]['TOTALVENDA'], 2, ',', '.');
		     	}

		     	$rowFilho[$j][$i]['VLRMEDIOCUP'] = "Valor Médio Cupom: ".$rowFilho[$j][$i]['VLRMEDIOCUP'] ;
		     	
		    }
	 	}
	 	
	 	return $rowFilho;
    }
    
    public function buildParamsFaturamento($conditions, $modalidades){    
        $conditions['CDFILIAL'] = implode($conditions['CDFILIAL'], '_');
        $conditions['TCDFILIAL'] = 'E';
        if( array_key_exists('CDFILICAIXA', $conditions) ) {
            $conditions['CDCAIXA'] = implode($conditions['CDFILICAIXA'], '_');
            $conditions['TCDCAIXA'] = 'F';
            unset($conditions['CDFILICAIXA']);
        } else {
            $conditions['CDCAIXA'] = null;
            $conditions['TCDCAIXA'] = 'T';    
        }
        
        if( array_key_exists('CDTIPOCONS', $conditions) ) {
            $conditions['CDTIPOCONS'] = implode($conditions['CDTIPOCONS'], '_');
            $conditions['TCDTIPOCONS'] = 'F';
        } else {
            $conditions['CDTIPOCONS'] = null;
            $conditions['TCDTIPOCONS'] = 'T';    
        }
        
        if( array_key_exists('MODALIDADE', $conditions) ) {
            $conditions['MODALIDADE'] = implode($conditions['MODALIDADE'], '_');
        } else {
            $conditions['MODALIDADE'] = $modalidades;
        }
        
        if(array_key_exists('DTENTRVENDA', $conditions)) {
            $conditions['DTVENDAINI'] = $conditions['DTENTRVENDA'][0];
            $conditions['DTVENDAFIN'] = $conditions['DTENTRVENDA'][1];
            unset($conditions['DTENTRVENDA']);
        }
        if (isset($conditions['INTERVALISTA']) && $conditions['INTERVALISTA'] == 'I'){
           if (empty($conditions['CDARVPRODF'])){
                $conditions['CDARVPRODF'] = $conditions['CDARVPRODI'];
           }
           $conditions['TCDPRODUTO'] = null;
           $conditions['CDPRODLIST'] = null;
           $conditions['PRODNIV'] = null;
        }elseif (isset($conditions['INTERVALISTA']) && $conditions['INTERVALISTA'] == 'D') {
           $conditions['PRODNIV'] = str_replace('%', '', str_replace('.', '', $conditions['PRODNIV'])).'%';
           $conditions['TCDPRODUTO'] = null;
           $conditions['CDPRODLIST'] = null;
           $conditions['CDARVPRODF'] = null;
           $conditions['CDARVPRODI'] = null;
        }
        elseif (isset($conditions['INTERVALISTA']) && $conditions['INTERVALISTA'] == 'L'){
           $conditions['CDPRODLIST'] = implode('_', $conditions['CDPRODUTO']);
           $conditions['TCDPRODUTO'] = null;
           $conditions['CDARVPRODF'] = null;
           $conditions['CDARVPRODI'] = null;
           $conditions['PRODNIV'] = null;
        }
        else{
           $conditions['TCDPRODUTO'] = 'T';
           $conditions['CDPRODLIST'] = null;
           $conditions['CDARVPRODF'] = null;
           $conditions['CDARVPRODI'] = null;
           $conditions['PRODNIV'] = null;
        }
       
        return $conditions;
    }
    
    public function getSQL($tipoRelatorio, $tipoProduto) {
        if($tipoRelatorio == 'A') {
            $MTC = "V.CDFILIAL = B.CDFILIAL)*1000), 2) AS MTC, ";
            $GROUP_BY = "IT.VRUNITVENDCL, ";
            $ORDER_BY = "";
            $ORDER_BY_ = "";
            $DATA = "BETWEEN :DTVENDAINI AND :DTVENDAFIN ";
            $DATA_FILOCAVE = "";
            $DATA_VENDA = "";
            $CAMPOS_SELECT = "ROUND((B.TOTALVEND * 100/ (SUM(TOTALVEND) OVER (PARTITION BY CDFILIAL, NRORG))), 5) VRPORVENDA, SUM(TOTALVEND) OVER (PARTITION BY CDFILIAL, NRORG) TOTALPORDATA, B.* FROM (SELECT PR.CDPRODUTO, PR.CDARVPROD, FILOCAVE.CDFILIAL, FILOCAVE.CDFILIAL || ' - ' || FILOCAVE.NMFILIAL AS LABELFILIAL, ";
            $CDPRODPROMOCAO = "";
        }else if($tipoRelatorio == 'S') {
            $MTC = "( ( INSTR( :CDFILIAL, V.CDFILIAL) <> 0 ) OR ( :TCDFILIAL = 'T' ) ) )*1000), 2) AS MTC, ";
            $GROUP_BY = "";
            $ORDER_BY = "";
            $ORDER_BY_ = "";
            $DATA = "BETWEEN :DTVENDAINI AND :DTVENDAFIN ";
            $DATA_FILOCAVE = "";
            $DATA_VENDA = "";
            $CAMPOS_SELECT = "ROUND((B.TOTALVEND * 100/ (SUM(TOTALVEND) OVER (PARTITION BY NRORG))), 5) VRPORVENDA, SUM(TOTALVEND) OVER (PARTITION BY NRORG) TOTALPORDATA, B.* FROM (SELECT PR.CDPRODUTO, PR.CDARVPROD, FILOCAVE.CDFILIAL, FILOCAVE.CDFILIAL || ' - ' || FILOCAVE.NMFILIAL AS LABELFILIAL, ";
            $CDPRODPROMOCAO = "";
        } else if($tipoRelatorio = 'D') {
            $MTC = "( ( INSTR( :CDFILIAL, V.CDFILIAL) <> 0 ) OR ( :TCDFILIAL = 'T' ) ) )*1000), 2) AS MTC, ";
            $GROUP_BY = "FILOCAVE.DTENTRVENDA, IT.VRUNITVENDCL, ";
            $ORDER_BY = "FILOCAVE.DTENTRVENDA, ";
            $ORDER_BY_ = "ORDER BY DTENTRVENDA2";
            $DATA = "= B.DTENTRVENDA2 ";
            $DATA_FILOCAVE = "FILOCAVE.DTENTRVENDA, ";
            $DATA_VENDA = "V.DTENTRVENDA, ";
            $CAMPOS_SELECT = "ROUND((B.TOTALVEND * 100/ (SUM(TOTALVEND) OVER (PARTITION BY DTENTRVENDA2, CDFILIAL, NRORG))), 5) VRPORVENDA, SUM(TOTALVEND) OVER (PARTITION BY DTENTRVENDA2, CDFILIAL, NRORG) TOTALPORDATA, B.* FROM (SELECT FILOCAVE.DTENTRVENDA AS DTENTRVENDA2, PR.CDPRODUTO, PR.CDARVPROD, FILOCAVE.CDFILIAL, FILOCAVE.CDFILIAL || ' - ' || FILOCAVE.NMFILIAL AS LABELFILIAL, ";
            $CDPRODPROMOCAO = "";
        }
        
        if($tipoProduto == 'T') {
            $CDPRODPROMOCAO = ", IT.CDPRODPROMOCAO";
        }
        
        $query = "
            SELECT ROUND((B.QTPRODVEND/
            (
            SELECT COUNT(V.NRSEQVENDA) AS MTCBASE
                    FROM VENDA V 
                    WHERE V.IDSITUVENDA = 'O' 
                       AND V.DTENTRVENDA ".$DATA."
                       AND V.NRORG = :NRORG
                       AND ".$MTC." 
                       ".$CAMPOS_SELECT." PR.NMPRODUTO,
                       IT.IDIMPPRGRPROMO,
                       SUM(TRUNC( IT.QTPRODVEND * (IT.VRUNITVEND + NVL( IT.VRUNITVENDCL, 0 ) ), 2 ) - NVL( IT.VRDESITVEND, 0 )) AS TOTALVEND,
                       PR.SGUNIDADE, IT.VRUNITVEND, SUM(TRUNC( IT.QTPRODVEND * (IT.VRUNITVEND + NVL( IT.VRUNITVENDCL, 0 ) ), 2 ) ) AS VALORVENDIDO,
                       SUM(IT.QTPRODVEND) AS QTPRODVEND, SUM(NVL( IT.VRDESITVEND, 0 ) ) AS VRDESITVEND, SUM(NVL( IT.VRACRITVEND, 0 ) ) AS ACRESCIMO,
                       FILOCAVE.NRORG,  FILOCAVE.CDPRODTAXAENTR, FILOCAVE.CDTIPOCONS, NVL(FILOCAVE.NMTIPOCONS, 'S/ CONSUMIDOR') AS NMTIPOCONS, FILOCAVE.MODALIDADE, 'Produtos Avulsos' as LABELPRODPROMOCAO".$CDPRODPROMOCAO."
                  FROM ITEMVENDA IT
                  JOIN PRODUTO PR 
                    ON IT.CDPRODUTO = PR.CDPRODUTO
                  JOIN (SELECT ".$DATA_FILOCAVE." FILOCAVE.IDSITUVENDA, FILOCAVE.NRSEQVENDA, FILOCAVE.CDCAIXA, FILOCAVE.NMCAIXA, FILOCAVE.CDLOJA, FILOCAVE.NMLOJA, FILOCAVE.CDFILIAL, FILOCAVE.NMFILIAL,
                                FILOCAVE.NRORG, FILOCAVE.CDPRODTAXASERV, FILOCAVE.CDCONSUMIDOR, C.CDTIPOCONS, TC.NMTIPOCONS, FILOCAVE.IDORIGEMVENDA, FILOCAVE.CDPRODTAXAENTR, FILOCAVE.MODALIDADE
                          FROM ( SELECT V.IDORIGEMVENDA, V.CDCLIENTE, V.CDCONSUMIDOR, ".$DATA_VENDA." V.IDSITUVENDA, V.NRSEQVENDA, FILOCA.CDCAIXA, FILOCA.NMCAIXA, FILOCA.CDLOJA, FILOCA.NMLOJA, FILOCA.CDFILIAL, FILOCA.NMFILIAL,
                                    FILOCA.NRORG, FILOCA.CDPRODTAXASERV, FILOCA.CDPRODTAXAENTR,
                                    CASE SUBSTR(V.IDORIGEMVENDA, 0, 3)
                                       WHEN 'DLV' THEN 'DELIVERY'
                                       WHEN 'MES' THEN 'MESA'
                                       WHEN 'BAL' THEN (CASE SUBSTR(V.IDORIGEMVENDA, 5, 7) WHEN 'AUT' THEN 'TERMINAL DE AUTO-ATENDIMENTO' ELSE 'BALCAO' END) 
                                       WHEN 'TAA' THEN 'TERMINAL DE AUTO-ATENDIMENTO'
                                       WHEN 'CMD' THEN 'COMANDA'
                                       WHEN 'AJU' THEN 'OUTROS'
                                       ELSE 'OUTROS'
                                     END AS MODALIDADE
                               FROM VENDA V
                               JOIN ( SELECT C.CDCAIXA, C.NMCAIXA, FILO.CDLOJA, FILO.NMLOJA, FILO.CDFILIAL, FILO.NMFILIAL, FILO.NRORG, FILO.CDPRODTAXASERV, FILO.CDPRODTAXAENTR
                                        FROM CAIXA C 
                                        JOIN ( SELECT L.CDLOJA, L.NMLOJA, FI.CDFILIAL, FI.NMFILIAL, FI.NRORG, L.CDPRODTAXASERV, L.CDPRODTAXAENTR
                                                 FROM LOJA L 
                                                 JOIN ( SELECT F.CDFILIAL, F.NMFILIAL, F.NRORG
                                                          FROM FILIAL F 
                                                         WHERE ( ( INSTR( :CDFILIAL, F.CDFILIAL ) <> 0 ) OR ( :TCDFILIAL = 'T' ) ) 
                                                           AND F.NRORG =:NRORG
                                                      ) FI 
                                                   ON L.CDFILIAL = FI.CDFILIAL
                                                  AND L.NRORG = FI.NRORG
                                             ) FILO 
                                          ON C.CDFILIAL = FILO.CDFILIAL
                                         AND C.CDLOJA = FILO.CDLOJA
                                         AND C.NRORG = FILO.NRORG
                                         AND ( ( INSTR( :CDCAIXA, C.CDCAIXA ) <> 0 ) OR ( :TCDCAIXA = 'T' ) )
                                     ) FILOCA 
                                  ON V.CDCAIXA = FILOCA.CDCAIXA
                                 AND V.CDLOJA = FILOCA.CDLOJA
                                 AND V.CDFILIAL = FILOCA.CDFILIAL
                                 AND V.NRORG = FILOCA.NRORG
                               WHERE V.IDSITUVENDA = 'O'
                                 AND V.DTENTRVENDA BETWEEN :DTVENDAINI AND :DTVENDAFIN
                                 AND (INSTR(:MODALIDADE, SUBSTR(V.IDORIGEMVENDA, 0, 3) ) > 0 OR INSTR(:MODALIDADE, SUBSTR(V.IDORIGEMVENDA, 5, 7) ) > 0)
                                 AND V.IDSITUVENDA IN( CASE SUBSTR(V.IDORIGEMVENDA, 0, 3)
                                                         WHEN 'DLV' THEN 'O'
                                                         WHEN 'MES' THEN 'O'
                                                         WHEN 'BAL' THEN 'O'
                                                         WHEN 'TAA' THEN 'O'
                                                         WHEN 'CMD' THEN 'O'
                                                         WHEN 'AJU' THEN V.IDSITUVENDA
                                                        END)
                           ) FILOCAVE 
                          LEFT JOIN CONSUMIDOR C
                            ON FILOCAVE.CDCONSUMIDOR = C.CDCONSUMIDOR 
                           AND FILOCAVE.CDCLIENTE = C.CDCLIENTE
                           AND FILOCAVE.NRORG = C.NRORG
                          LEFT JOIN TIPOCONS TC
                            ON C.CDTIPOCONS = TC.CDTIPOCONS
                         WHERE ( ( INSTR( :CDTIPOCONS, C.CDTIPOCONS) <> 0 ) OR ( :TCDTIPOCONS = 'T' ) )
                        ) FILOCAVE
                    ON FILOCAVE.CDFILIAL = IT.CDFILIAL
                   AND FILOCAVE.CDCAIXA = IT.CDCAIXA
                   AND FILOCAVE.NRSEQVENDA = IT.NRSEQVENDA
                   AND FILOCAVE.NRORG = IT.NRORG
                 WHERE IT.CDPRODUTO <> NVL( FILOCAVE.CDPRODTAXASERV, 0 )
                   AND IT.CDPRODUTO <> NVL( FILOCAVE.CDPRODTAXAENTR, 0 )
                   AND (((((INSTR(:CDPRODLIST, PR.CDPRODUTO) > 0 ) OR (PR.CDARVPROD BETWEEN :CDARVPRODI AND :CDARVPRODF ))) OR (PR.CDARVPROD LIKE :PRODNIV)) OR (:TCDPRODUTO = 'T'))
                 GROUP BY ".$GROUP_BY." PR.CDPRODUTO, PR.CDARVPROD, FILOCAVE.CDFILIAL, FILOCAVE.NMFILIAL, PR.NMPRODUTO,PR.SGUNIDADE, IT.VRUNITVEND,
                          IT.IDIMPPRGRPROMO, FILOCAVE.NRORG,  FILOCAVE.CDPRODTAXAENTR, FILOCAVE.CDTIPOCONS, FILOCAVE.NMTIPOCONS, FILOCAVE.MODALIDADE".$CDPRODPROMOCAO."
            
                 ORDER BY ".$ORDER_BY." FILOCAVE.CDFILIAL, PR.CDARVPROD) B ".$ORDER_BY_."
        ";
        return strval(trim($query));
    }
   
    public function getSQLFilho($tipoRelatorio) {
        if($tipoRelatorio == 'A') {
            $SELECT = "";
            $DATAMTC = "BETWEEN :P_DTINI AND :P_DTFIM";
            $VENDA = "";
            $PARTITION = "VE.CDFILIAL, ";
            $GROUP_BY = "";
        }else if($tipoRelatorio == 'S') {
            $SELECT = "";
            $DATAMTC = "BETWEEN :P_DTINI AND :P_DTFIM";
            $VENDA = "";
            $PARTITION = "";
            $GROUP_BY = "";
        } else if($tipoRelatorio = 'D') {
            $SELECT = "VE.DTENTRVENDA AS DTENTRVENDA2, ";
            $DATAMTC = "= VE.DTENTRVENDA";
            $VENDA = ", TO_CHAR(V.DTENTRVENDA, 'DD/MM/YYYY') AS DTENTRVENDA";
            $PARTITION = "VE.CDFILIAL, VE.DTENTRVENDA, ";
            $GROUP_BY = ", VE.DTENTRVENDA";
        }
        
        $query = "
            (SELECT VE.NRORG, VE.CDFILIAL, VE.MODALIDADE, VE.CDTIPOCONS, VE.NMTIPOCONS, ES.CDPRODUTO, P.CDARVPROD, P.NMPRODUTO, SUM(ES.QTITVENDAEST) AS QTPRODVEND, SUM((CASE WHEN IT.CDPRODUTO = ES.CDPRODUTO THEN NVL( IT.VRDESITVEND, 0 ) ELSE NVL( ES.VRDESITVENDAEST, 0 ) END) ) AS VRDESITVEND, SUM(NVL( IT.VRACRITVEND, 0 ) ) AS ACRESCIMO,
            ES.VRUNVENDAEST AS VRUNITVEND, P.CDBARPRODUTO, P.SGUNIDADE, IT.CDPRODPROMOCAO, ".$SELECT."
            ROUND((SUM(ES.QTITVENDAEST)/
            (
                SELECT COUNT(V.NRSEQVENDA) AS MTCBASE
                FROM VENDA V 
                WHERE V.IDSITUVENDA = 'O' 
                  AND V.DTENTRVENDA ".$DATAMTC."
                  AND V.NRORG = :NRORG
                  AND V.CDFILIAL = VE.CDFILIAL)*1000), 2) AS MTC,
            SUM(TRUNC(ES.QTITVENDAEST * (ES.VRUNVENDAEST), 2 ) - (CASE WHEN IT.CDPRODUTO = ES.CDPRODUTO THEN NVL( IT.VRDESITVEND, 0 ) ELSE NVL( ES.VRDESITVENDAEST, 0 ) END) ) AS TOTALVEND ,
            SUM(SUM(TRUNC(ES.QTITVENDAEST * (ES.VRUNVENDAEST), 2 ) - (CASE WHEN IT.CDPRODUTO = ES.CDPRODUTO THEN NVL( IT.VRDESITVEND, 0 ) ELSE NVL( ES.VRDESITVENDAEST, 0 ) END)))  OVER (PARTITION BY ".$PARTITION." VE.NRORG) TOTALPORDATA,
            ROUND(((SUM(TRUNC(ES.QTITVENDAEST * (ES.VRUNVENDAEST), 2 ) - (CASE WHEN IT.CDPRODUTO = ES.CDPRODUTO THEN NVL( IT.VRDESITVEND, 0 ) ELSE NVL( ES.VRDESITVENDAEST, 0 ) END))) * 100/ (SUM((SUM(TRUNC(ES.QTITVENDAEST * (IT.VRUNITVEND + NVL( IT.VRUNITVENDCL, 0 ) ), 2 ) - NVL( IT.VRDESITVEND, 0 )))) OVER (PARTITION BY ".$PARTITION." VE.NRORG))), 5) VRPORVENDA,
            SUM(TRUNC(ES.QTITVENDAEST * (ES.VRUNVENDAEST), 2 ) ) AS VALORVENDIDO,
            SUM(TRUNC(ES.VRUNVENDAEST * ES.QTITVENDAEST,2) - (CASE WHEN IT.CDPRODUTO = ES.CDPRODUTO THEN NVL( IT.VRDESITVEND, 0 ) ELSE NVL( ES.VRDESITVENDAEST, 0 ) END)) AS TOTALVENDFIL
                  
               FROM ITEMVENDA IT
               
               
               JOIN (SELECT FILOCA.NRORG, FILOCA.CDFILIAL, FILOCA.CDCAIXA,
                        CASE SUBSTR(V.IDORIGEMVENDA, 0, 3)
                                                       WHEN 'DLV' THEN 'DELIVERY'
                                                       WHEN 'MES' THEN 'MESA'
                                                       WHEN 'BAL' THEN (CASE SUBSTR(V.IDORIGEMVENDA, 5, 7) WHEN 'AUT' THEN 'TERMINAL DE AUTO-ATENDIMENTO' ELSE 'BALCAO' END) 
                                                       WHEN 'TAA' THEN 'TERMINAL DE AUTO-ATENDIMENTO'
                                                       WHEN 'CMD' THEN 'COMANDA'
                                                       WHEN 'AJU' THEN 'OUTROS'
                                                       ELSE 'OUTROS'
                                                     END AS MODALIDADE,
                        CM.CDTIPOCONS, NVL(TC.NMTIPOCONS, 'S/ CONSUMIDOR') AS NMTIPOCONS, V.NRSEQVENDA ".$VENDA."
                        
    				  FROM VENDA V
    				  JOIN (SELECT C.CDCAIXA, FILO.CDLOJA, FILO.CDFILIAL, FILO.NRORG
                               FROM CAIXA C
    						   JOIN (SELECT L.CDLOJA, FI.CDFILIAL, FI.NRORG
    									FROM LOJA L
    									JOIN ( SELECT F.CDFILIAL, F.NRORG
    											FROM FILIAL F
    											WHERE (F.CDFILIAL = :CDFILIAL)) FI
    									  ON L.CDFILIAL = FI.CDFILIAL
    									 ) FILO
    							 ON C.CDFILIAL = FILO.CDFILIAL
    							AND C.CDLOJA = FILO.CDLOJA) FILOCA
    					 ON V.CDCAIXA = FILOCA.CDCAIXA
    					AND V.CDLOJA = FILOCA.CDLOJA
    					AND V.CDFILIAL = FILOCA.CDFILIAL
                        
                      LEFT JOIN CONSUMIDOR CM
                             ON V.CDCONSUMIDOR = CM.CDCONSUMIDOR 
                            AND V.CDCLIENTE = CM.CDCLIENTE
                               
                      LEFT JOIN TIPOCONS TC
                             ON CM.CDTIPOCONS = TC.CDTIPOCONS
    			
    				  WHERE V.IDSITUVENDA = 'O'
                        AND (V.DTENTRVENDA BETWEEN :P_DTINI AND :P_DTFIM)
                        AND (INSTR(:MODALIDADE, SUBSTR(V.IDORIGEMVENDA, 0, 3)) > 0)
                        AND ((INSTR(:CDTIPOCONS, CM.CDTIPOCONS) <> 0) OR (:TCDTIPOCONS = 'T' ))
                        AND ( ( INSTR( :CDCAIXA, FILOCA.CDCAIXA ) <> 0 ) OR ( :TCDCAIXA = 'T' ) )) VE
                        
                 ON (IT.CDFILIAL = VE.CDFILIAL)
                AND (IT.CDCAIXA = VE.CDCAIXA)
                AND (IT.NRSEQVENDA = VE.NRSEQVENDA)
                
               JOIN ITEMVENDAEST ES
                 ON (IT.CDFILIAL = ES.CDFILIAL)
                AND (IT.CDCAIXA = ES.CDCAIXA)
                AND (IT.NRSEQVENDA = ES.NRSEQVENDA)
                AND (IT.NRSEQUITVEND = ES.NRSEQUITVEND)
               
              JOIN PRODUTO P
                ON (ES.CDPRODUTO = P.CDPRODUTO)
                
              WHERE (IT.CDPRODUTO = IT.CDPRODPROMOCAO)
                AND (IT.CDPRODPROMOCAO = :CDPRODPAI)
                AND (:TIPO= '1')
                AND (EXISTS (SELECT ES.CDFILIAL
                          FROM ITEMVENDAEST ES
                         WHERE (ES.CDFILIAL     = IT.CDFILIAL    )
                           AND (ES.CDCAIXA      = IT.CDCAIXA     )
                           AND (ES.NRSEQVENDA   = IT.NRSEQVENDA  )
                           AND (ES.NRSEQUITVEND = IT.NRSEQUITVEND))) 
              GROUP BY VE.CDFILIAL, ES.CDPRODUTO, P.CDARVPROD, P.NMPRODUTO, ES.VRDESITVENDAEST,
              IT.VRACRITVEND, VE.MODALIDADE, IT.CDPRODPROMOCAO,
              VE.CDTIPOCONS, VE.NMTIPOCONS, P.SGUNIDADE, ES.VRUNVENDAEST, VE.NRORG, P.CDBARPRODUTO ".$GROUP_BY.")
       	
    	    UNION
    	
            (SELECT VE.NRORG, VE.CDFILIAL, VE.MODALIDADE, VE.CDTIPOCONS, VE.NMTIPOCONS, IT.CDPRODUTO, P.CDARVPROD, P.NMPRODUTO, SUM(IT.QTPRODVEND) AS QTPRODVEND, SUM(NVL( IT.VRDESITVEND, 0 ) ) AS VRDESITVEND, SUM(NVL( IT.VRACRITVEND, 0 ) ) AS ACRESCIMO,
            IT.VRUNITVEND, P.CDBARPRODUTO, P.SGUNIDADE, IT.CDPRODPROMOCAO, ".$SELECT."
            ROUND((SUM(IT.QTPRODVEND)/
            (
                SELECT COUNT(V.NRSEQVENDA) AS MTCBASE
                FROM VENDA V 
                WHERE V.IDSITUVENDA = 'O' 
                  AND V.DTENTRVENDA ".$DATAMTC."
                  AND V.NRORG = :NRORG
                  AND V.CDFILIAL = VE.CDFILIAL)*1000), 2) AS MTC,
            SUM(TRUNC( IT.QTPRODVEND * (IT.VRUNITVEND + NVL( IT.VRUNITVENDCL, 0 ) ), 2 ) - NVL( IT.VRDESITVEND, 0 )) AS TOTALVEND,
            SUM((SUM(TRUNC( IT.QTPRODVEND * (IT.VRUNITVEND + NVL( IT.VRUNITVENDCL, 0 ) ), 2 ) - NVL( IT.VRDESITVEND, 0 )))) OVER (PARTITION BY ".$PARTITION." VE.NRORG) TOTALPORDATA,
            ROUND(((SUM(TRUNC( IT.QTPRODVEND * (IT.VRUNITVEND + NVL( IT.VRUNITVENDCL, 0 ) ), 2 ) - NVL( IT.VRDESITVEND, 0 ))) * 100/ (SUM((SUM(TRUNC( IT.QTPRODVEND * (IT.VRUNITVEND + NVL( IT.VRUNITVENDCL, 0 ) ), 2 ) - NVL( IT.VRDESITVEND, 0 )))) OVER (PARTITION BY ".$PARTITION." VE.NRORG))), 5) VRPORVENDA,
            SUM(TRUNC( IT.QTPRODVEND * (IT.VRUNITVEND + NVL( IT.VRUNITVENDCL, 0 ) ), 2 ) ) AS VALORVENDIDO,
            SUM((TRUNC(IT.QTPRODVEND * (IT.VRUNITVEND + NVL(IT.VRUNITVENDCL, 0)), 2)) - NVL(IT.VRDESITVEND, 0) + NVL(IT.VRACRITVEND, 0)) AS TOTALVENDFIL
                  
               FROM ITEMVENDA IT
               
               JOIN (SELECT FILOCA.NRORG, FILOCA.CDFILIAL, FILOCA.CDCAIXA,
                        CASE SUBSTR(V.IDORIGEMVENDA, 0, 3)
                                                       WHEN 'DLV' THEN 'DELIVERY'
                                                       WHEN 'MES' THEN 'MESA'
                                                       WHEN 'BAL' THEN (CASE SUBSTR(V.IDORIGEMVENDA, 5, 7) WHEN 'AUT' THEN 'TERMINAL DE AUTO-ATENDIMENTO' ELSE 'BALCAO' END) 
                                                       WHEN 'TAA' THEN 'TERMINAL DE AUTO-ATENDIMENTO'
                                                       WHEN 'CMD' THEN 'COMANDA'
                                                       WHEN 'AJU' THEN 'OUTROS'
                                                       ELSE 'OUTROS'
                                                     END AS MODALIDADE,
                        CM.CDTIPOCONS, NVL(TC.NMTIPOCONS, 'S/ CONSUMIDOR') AS NMTIPOCONS, V.NRSEQVENDA ".$VENDA."
                        
    				  FROM VENDA V
    				  JOIN (SELECT C.CDCAIXA, FILO.CDLOJA, FILO.CDFILIAL, FILO.NRORG
                               FROM CAIXA C
    						   JOIN (SELECT L.CDLOJA, FI.CDFILIAL, FI.NRORG
    									FROM LOJA L
    									JOIN ( SELECT F.CDFILIAL, F.NRORG
    											FROM FILIAL F
    											WHERE (F.CDFILIAL = :CDFILIAL)) FI
    									  ON L.CDFILIAL = FI.CDFILIAL
    									 ) FILO
    							 ON C.CDFILIAL = FILO.CDFILIAL
    							AND C.CDLOJA = FILO.CDLOJA) FILOCA
    					 ON V.CDCAIXA = FILOCA.CDCAIXA
    					AND V.CDLOJA = FILOCA.CDLOJA
    					AND V.CDFILIAL = FILOCA.CDFILIAL
                        
                      LEFT JOIN CONSUMIDOR CM
                             ON V.CDCONSUMIDOR = CM.CDCONSUMIDOR 
                            AND V.CDCLIENTE = CM.CDCLIENTE
                               
                      LEFT JOIN TIPOCONS TC
                             ON CM.CDTIPOCONS = TC.CDTIPOCONS
    			
    				  WHERE V.IDSITUVENDA = 'O'
                        AND (V.DTENTRVENDA BETWEEN :P_DTINI AND :P_DTFIM)
                        AND (INSTR(:MODALIDADE, SUBSTR(V.IDORIGEMVENDA, 0, 3)) > 0)
                        AND ((INSTR(:CDTIPOCONS, CM.CDTIPOCONS) <> 0) OR (:TCDTIPOCONS = 'T' ))
                        AND ( ( INSTR( :CDCAIXA, FILOCA.CDCAIXA ) <> 0 ) OR ( :TCDCAIXA = 'T' ) )) VE
                        
                 ON (IT.CDFILIAL = VE.CDFILIAL)
                AND (IT.CDCAIXA = VE.CDCAIXA)
                AND (IT.NRSEQVENDA = VE.NRSEQVENDA)
               
              JOIN PRODUTO P
                ON (IT.CDPRODUTO = P.CDPRODUTO)
                     
              WHERE (IT.CDPRODPROMOCAO = :CDPRODPAI)
                AND (:TIPO= '2')
                AND (NOT EXISTS (SELECT ES.CDFILIAL
                              FROM ITEMVENDAEST ES
                             WHERE (ES.CDFILIAL     = IT.CDFILIAL    )
                               AND (ES.CDCAIXA      = IT.CDCAIXA     )
                               AND (ES.NRSEQVENDA   = IT.NRSEQVENDA  )
                               AND (ES.NRSEQUITVEND = IT.NRSEQUITVEND)))
              GROUP BY VE.CDFILIAL, IT.CDPRODUTO, P.CDARVPROD, P.NMPRODUTO, IT.VRDESITVEND,
              IT.VRACRITVEND, VE.MODALIDADE, IT.CDPRODPROMOCAO, VE.CDTIPOCONS, VE.NMTIPOCONS, P.SGUNIDADE, IT.VRUNITVEND,
              IT.VRUNITVENDCL, VE.NRORG, P.CDBARPRODUTO ".$GROUP_BY.")
    	      ORDER BY 9 DESC
        ";
        return strval(trim($query));
    }
	
	public function getSQLPai($tipoRelatorio) {
        if($tipoRelatorio == 'A') {
            $DATA = "";
            $GROUP_DATA = "";
            $ORDER_DATA = "";
        }else if($tipoRelatorio == 'S') {
            $DATA = "";
            $GROUP_DATA = "";
            $ORDER_DATA = "";
        } else if($tipoRelatorio = 'D') {
            $DATA = ", TO_CHAR(VE.DTENTRVENDA, 'DD/MM/YYYY') AS DTENTRVENDA";
            $GROUP_DATA = ", VE.DTENTRVENDA";
            $ORDER_DATA = ", 16";
        }
        
        $query = "
            SELECT IT.CDPRODUTO AS CDPRODPAI, PR.NMPRODUTO AS NMPRODPAI, '1' AS TIPO, PR.CDARVPROD, PR.CDBARPRODUTO AS CDBARPRODPAI, IT.CDFILIAL, FI.NMFILIAL,
                   COUNT(DISTINCT VE.CDFILIAL||VE.CDCAIXA||VE.NRSEQVENDA) AS NRCUPONS, SUM(IT.QTPRODVEND) AS QUANTPRODPAI, 
                   SUM((TRUNC(IT.QTPRODVEND * (IT.VRUNITVEND + NVL(IT.VRUNITVENDCL,0)),2)) - NVL(IT.VRDESITVEND,0) + NVL(IT.VRACRITVEND,0)) AS TOTALVENDA,
                   0 AS QTVENDIDA, 
                   IT.CDPRODPROMOCAO||' - '||PR.NMPRODUTO AS LABELPRODPROMOCAO, IT.NRORG, CASE SUBSTR(VE.IDORIGEMVENDA, 0, 3) WHEN 'DLV' THEN 'DELIVERY'
                   WHEN 'MES' THEN 'MESA' WHEN 'BAL' THEN 'BALCAO' WHEN 'TAA' THEN 'TERMINAL DE AUTO-ATENDIMENTO' WHEN 'CMD' THEN 'COMANDA'
                   WHEN 'AJU' THEN 'OUTROS' ELSE 'OUTROS' END AS NMMODALIDADE, SUBSTR(VE.IDORIGEMVENDA, 0, 3) AS IDORIGEMVENDA".$DATA."
    	      FROM ITEMVENDA IT, VENDA VE, PRODUTO PR, FILIAL FI, CONSUMIDOR C
    	     WHERE (IT.CDFILIAL = FI.CDFILIAL)
               AND (IT.CDFILIAL = VE.CDFILIAL)
               AND (IT.CDCAIXA = VE.CDCAIXA)
               AND (IT.NRSEQVENDA = VE.NRSEQVENDA)
               AND (IT.CDPRODUTO = PR.CDPRODUTO)
               AND (IT.CDPRODUTO = IT.CDPRODPROMOCAO)
               AND (VE.IDSITUVENDA = 'O')
               AND VE.CDCONSUMIDOR = C.CDCONSUMIDOR(+) 
               AND VE.CDCLIENTE = C.CDCLIENTE(+)
               AND (EXISTS (SELECT ES.CDFILIAL 
                              FROM ITEMVENDAEST ES
                             WHERE (ES.CDFILIAL = IT.CDFILIAL)
                               AND (ES.CDCAIXA = IT.CDCAIXA)
                               AND (ES.NRSEQVENDA = IT.NRSEQVENDA)
                               AND (ES.NRSEQUITVEND = IT.NRSEQUITVEND)))
              AND (VE.DTENTRVENDA BETWEEN :P_DTINI AND :P_DTFIM)
              AND (((((INSTR(:CDPRODLIST, PR.CDPRODUTO) > 0 ) OR (PR.CDARVPROD BETWEEN :PRODINI AND :PRODFIM ))) OR (PR.CDARVPROD LIKE :PRODNIV)) OR (:TCDPRODUTO = 'T'))
              AND ((INSTR(:CDFILIAL, IT.CDFILIAL) <> 0) OR (:P_TCDFILIAL = 'T'))
              AND (INSTR(:MODALIDADE, SUBSTR(VE.IDORIGEMVENDA, 0, 3)) > 0 OR INSTR(:MODALIDADE, SUBSTR(VE.IDORIGEMVENDA, 5, 7)) > 0)
              AND ((INSTR(:CDTIPOCONS, C.CDTIPOCONS) <> 0) OR (:TCDTIPOCONS = 'T' ))
              AND ((INSTR(:CDCAIXA, VE.CDCAIXA) <> 0 ) OR (:TCDCAIXA = 'T'))
    	    GROUP BY IT.CDFILIAL, FI.NMFILIAL, IT.CDPRODUTO, PR.NMPRODUTO, PR.CDARVPROD, PR.CDBARPRODUTO, IT.CDPRODPROMOCAO, IT.NRORG, SUBSTR(VE.IDORIGEMVENDA, 0, 3)".$GROUP_DATA."
    	 
    	    UNION
    	    
    	    SELECT IT.CDPRODPROMOCAO AS CDPRODPAI, PR.NMPRODUTO AS NMPRODPAI, '2' AS TIPO, PR.CDARVPROD, PR.CDBARPRODUTO AS CDBARPRODPAI, IT.CDFILIAL, FI.NMFILIAL,
                   COUNT(DISTINCT VE.CDFILIAL||VE.CDCAIXA||VE.NRSEQVENDA) AS NRCUPONS, SUM(IT.QTPRODVEND) AS QUANTPRODPAI, 
                   SUM((TRUNC(IT.QTPRODVEND * (IT.VRUNITVEND + NVL(IT.VRUNITVENDCL,0)),2)) - NVL(IT.VRDESITVEND,0) + NVL(IT.VRACRITVEND,0)) AS TOTALVENDA,
                   COUNT(DISTINCT IT.CDFILIAL||IT.CDCAIXA||IT.NRSEQVENDA||IT.NRSEQPRODCOMIT) AS QTVENDIDA,
                   IT.CDPRODPROMOCAO||' - '||PR.NMPRODUTO AS LABELPRODPROMOCAO, IT.NRORG, CASE SUBSTR(VE.IDORIGEMVENDA, 0, 3) WHEN 'DLV' THEN 'DELIVERY'
                   WHEN 'MES' THEN 'MESA' WHEN 'BAL' THEN 'BALCAO' WHEN 'TAA' THEN 'TERMINAL DE AUTO-ATENDIMENTO' WHEN 'CMD' THEN 'COMANDA'
                   WHEN 'AJU' THEN 'OUTROS' ELSE 'OUTROS' END AS NMMODALIDADE, SUBSTR(VE.IDORIGEMVENDA, 0, 3) AS IDORIGEMVENDA".$DATA."
    	      FROM ITEMVENDA IT, PRODUTO PR, VENDA VE, FILIAL FI, CONSUMIDOR C
    	     WHERE (IT.CDPRODPROMOCAO = PR.CDPRODUTO)
    	       AND (IT.CDFILIAL = FI.CDFILIAL)
    	       AND (IT.CDFILIAL = VE.CDFILIAL) 
    	       AND (IT.CDCAIXA = VE.CDCAIXA) 
    	       AND (IT.NRSEQVENDA = VE.NRSEQVENDA)
    	       AND (VE.IDSITUVENDA = 'O')
    	       AND VE.CDCONSUMIDOR = C.CDCONSUMIDOR(+) 
               AND VE.CDCLIENTE = C.CDCLIENTE(+)
    	       AND (IT.CDPRODPROMOCAO IS NOT NULL)
    	       AND (NOT EXISTS (SELECT ES.CDFILIAL
                      FROM ITEMVENDAEST ES
                     WHERE (ES.CDFILIAL     = IT.CDFILIAL    )
                       AND (ES.CDCAIXA      = IT.CDCAIXA     )
                       AND (ES.NRSEQVENDA   = IT.NRSEQVENDA  )
                       AND (ES.NRSEQUITVEND = IT.NRSEQUITVEND)))
    	       AND (VE.DTENTRVENDA BETWEEN :P_DTINI AND :P_DTFIM)
               AND (((((INSTR(:CDPRODLIST, PR.CDPRODUTO) > 0 ) OR (PR.CDARVPROD BETWEEN :PRODINI AND :PRODFIM ))) OR (PR.CDARVPROD LIKE :PRODNIV)) OR (:TCDPRODUTO = 'T'))
    	       AND ((INSTR(:CDFILIAL, IT.CDFILIAL) <> 0) OR (:P_TCDFILIAL = 'T'))
    	       AND (INSTR(:MODALIDADE, SUBSTR(VE.IDORIGEMVENDA, 0, 3) ) > 0 OR INSTR(:MODALIDADE, SUBSTR(VE.IDORIGEMVENDA, 5, 7) ) > 0)
    	       AND ((INSTR(:CDTIPOCONS, C.CDTIPOCONS) <> 0) OR (:TCDTIPOCONS = 'T' ))
    	       AND ((INSTR(:CDCAIXA, VE.CDCAIXA) <> 0 ) OR (:TCDCAIXA = 'T'))
    	     GROUP BY IT.CDFILIAL, FI.NMFILIAL, IT.CDPRODPROMOCAO, PR.NMPRODUTO, PR.CDARVPROD, PR.CDBARPRODUTO, IT.NRORG, SUBSTR(VE.IDORIGEMVENDA, 0, 3)".$GROUP_DATA."
    	     ORDER BY 6, 2".$ORDER_DATA."
        ";
        
        return strval(trim($query));
    }
	
	const GET_QT_PROD_PROM = "
	    SELECT NVL(SUM(QTPRGRUPPROMOC),1) AS NRITEMPROMO
          FROM GRUPROMOCPROD
         WHERE (CDPRODPROMOCAO = :CDPRODPAI) 
           AND (:TIPO = '2' )
           AND (:DTVENDAFIN  BETWEEN NVL(DTINIVGGRPROMO, :DTVENDAINI) AND NVL(DTFINVGGRPROMO, :DTVENDAFIN))
	";
}